@@ -23,6 +23,7 @@ from tencentcloud.dcdb.v20180411 import models
 class DcdbClient(AbstractClient):
     _apiVersion = '2018-04-11'
     _endpoint = 'dcdb.tencentcloudapi.com'
+    _service = 'dcdb'
 
 
     def CloneAccount(self, request):
@@ -700,6 +701,34 @@ class DcdbClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeUserTasks(self, request):
+        """本接口（DescribeUserTasks）用于拉取用户任务列表
+
+        :param request: Request instance for DescribeUserTasks.
+        :type request: :class:`tencentcloud.dcdb.v20180411.models.DescribeUserTasksRequest`
+        :rtype: :class:`tencentcloud.dcdb.v20180411.models.DescribeUserTasksResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeUserTasks", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeUserTasksResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def FlushBinlog(self, request):
         """相当于在所有分片的mysqld中执行flush logs，完成切分的binlog将展示在各个分片控制台binlog列表里。
 
